server

package
v0.0.0-...-315b6fa Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 23, 2026 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the server type in the database.
	Label = "server"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldHostname holds the string denoting the hostname field in the database.
	FieldHostname = "hostname"
	// FieldArch holds the string denoting the arch field in the database.
	FieldArch = "arch"
	// FieldOs holds the string denoting the os field in the database.
	FieldOs = "os"
	// FieldVersion holds the string denoting the version field in the database.
	FieldVersion = "version"
	// FieldChannel holds the string denoting the channel field in the database.
	FieldChannel = "channel"
	// FieldUpdateStatus holds the string denoting the update_status field in the database.
	FieldUpdateStatus = "update_status"
	// FieldUpdateMessage holds the string denoting the update_message field in the database.
	FieldUpdateMessage = "update_message"
	// FieldUpdateWhen holds the string denoting the update_when field in the database.
	FieldUpdateWhen = "update_when"
	// FieldNatsComponent holds the string denoting the nats_component field in the database.
	FieldNatsComponent = "nats_component"
	// FieldOcspComponent holds the string denoting the ocsp_component field in the database.
	FieldOcspComponent = "ocsp_component"
	// FieldConsoleComponent holds the string denoting the console_component field in the database.
	FieldConsoleComponent = "console_component"
	// FieldAgentWorkerComponent holds the string denoting the agent_worker_component field in the database.
	FieldAgentWorkerComponent = "agent_worker_component"
	// FieldNotificationWorkerComponent holds the string denoting the notification_worker_component field in the database.
	FieldNotificationWorkerComponent = "notification_worker_component"
	// FieldCertManagerWorkerComponent holds the string denoting the cert_manager_worker_component field in the database.
	FieldCertManagerWorkerComponent = "cert_manager_worker_component"
	// Table holds the table name of the server in the database.
	Table = "servers"
)

Variables

Columns holds all SQL columns for server fields.

Functions

func AgentWorkerComponent

func AgentWorkerComponent(v bool) predicate.Server

AgentWorkerComponent applies equality check predicate on the "agent_worker_component" field. It's identical to AgentWorkerComponentEQ.

func AgentWorkerComponentEQ

func AgentWorkerComponentEQ(v bool) predicate.Server

AgentWorkerComponentEQ applies the EQ predicate on the "agent_worker_component" field.

func AgentWorkerComponentIsNil

func AgentWorkerComponentIsNil() predicate.Server

AgentWorkerComponentIsNil applies the IsNil predicate on the "agent_worker_component" field.

func AgentWorkerComponentNEQ

func AgentWorkerComponentNEQ(v bool) predicate.Server

AgentWorkerComponentNEQ applies the NEQ predicate on the "agent_worker_component" field.

func AgentWorkerComponentNotNil

func AgentWorkerComponentNotNil() predicate.Server

AgentWorkerComponentNotNil applies the NotNil predicate on the "agent_worker_component" field.

func And

func And(predicates ...predicate.Server) predicate.Server

And groups predicates with the AND operator between them.

func Arch

func Arch(v string) predicate.Server

Arch applies equality check predicate on the "arch" field. It's identical to ArchEQ.

func ArchContains

func ArchContains(v string) predicate.Server

ArchContains applies the Contains predicate on the "arch" field.

func ArchContainsFold

func ArchContainsFold(v string) predicate.Server

ArchContainsFold applies the ContainsFold predicate on the "arch" field.

func ArchEQ

func ArchEQ(v string) predicate.Server

ArchEQ applies the EQ predicate on the "arch" field.

func ArchEqualFold

func ArchEqualFold(v string) predicate.Server

ArchEqualFold applies the EqualFold predicate on the "arch" field.

func ArchGT

func ArchGT(v string) predicate.Server

ArchGT applies the GT predicate on the "arch" field.

func ArchGTE

func ArchGTE(v string) predicate.Server

ArchGTE applies the GTE predicate on the "arch" field.

func ArchHasPrefix

func ArchHasPrefix(v string) predicate.Server

ArchHasPrefix applies the HasPrefix predicate on the "arch" field.

func ArchHasSuffix

func ArchHasSuffix(v string) predicate.Server

ArchHasSuffix applies the HasSuffix predicate on the "arch" field.

func ArchIn

func ArchIn(vs ...string) predicate.Server

ArchIn applies the In predicate on the "arch" field.

func ArchLT

func ArchLT(v string) predicate.Server

ArchLT applies the LT predicate on the "arch" field.

func ArchLTE

func ArchLTE(v string) predicate.Server

ArchLTE applies the LTE predicate on the "arch" field.

func ArchNEQ

func ArchNEQ(v string) predicate.Server

ArchNEQ applies the NEQ predicate on the "arch" field.

func ArchNotIn

func ArchNotIn(vs ...string) predicate.Server

ArchNotIn applies the NotIn predicate on the "arch" field.

func CertManagerWorkerComponent

func CertManagerWorkerComponent(v bool) predicate.Server

CertManagerWorkerComponent applies equality check predicate on the "cert_manager_worker_component" field. It's identical to CertManagerWorkerComponentEQ.

func CertManagerWorkerComponentEQ

func CertManagerWorkerComponentEQ(v bool) predicate.Server

CertManagerWorkerComponentEQ applies the EQ predicate on the "cert_manager_worker_component" field.

func CertManagerWorkerComponentIsNil

func CertManagerWorkerComponentIsNil() predicate.Server

CertManagerWorkerComponentIsNil applies the IsNil predicate on the "cert_manager_worker_component" field.

func CertManagerWorkerComponentNEQ

func CertManagerWorkerComponentNEQ(v bool) predicate.Server

CertManagerWorkerComponentNEQ applies the NEQ predicate on the "cert_manager_worker_component" field.

func CertManagerWorkerComponentNotNil

func CertManagerWorkerComponentNotNil() predicate.Server

CertManagerWorkerComponentNotNil applies the NotNil predicate on the "cert_manager_worker_component" field.

func ChannelEQ

func ChannelEQ(v Channel) predicate.Server

ChannelEQ applies the EQ predicate on the "channel" field.

func ChannelIn

func ChannelIn(vs ...Channel) predicate.Server

ChannelIn applies the In predicate on the "channel" field.

func ChannelNEQ

func ChannelNEQ(v Channel) predicate.Server

ChannelNEQ applies the NEQ predicate on the "channel" field.

func ChannelNotIn

func ChannelNotIn(vs ...Channel) predicate.Server

ChannelNotIn applies the NotIn predicate on the "channel" field.

func ChannelValidator

func ChannelValidator(c Channel) error

ChannelValidator is a validator for the "channel" field enum values. It is called by the builders before save.

func ConsoleComponent

func ConsoleComponent(v bool) predicate.Server

ConsoleComponent applies equality check predicate on the "console_component" field. It's identical to ConsoleComponentEQ.

func ConsoleComponentEQ

func ConsoleComponentEQ(v bool) predicate.Server

ConsoleComponentEQ applies the EQ predicate on the "console_component" field.

func ConsoleComponentIsNil

func ConsoleComponentIsNil() predicate.Server

ConsoleComponentIsNil applies the IsNil predicate on the "console_component" field.

func ConsoleComponentNEQ

func ConsoleComponentNEQ(v bool) predicate.Server

ConsoleComponentNEQ applies the NEQ predicate on the "console_component" field.

func ConsoleComponentNotNil

func ConsoleComponentNotNil() predicate.Server

ConsoleComponentNotNil applies the NotNil predicate on the "console_component" field.

func Hostname

func Hostname(v string) predicate.Server

Hostname applies equality check predicate on the "hostname" field. It's identical to HostnameEQ.

func HostnameContains

func HostnameContains(v string) predicate.Server

HostnameContains applies the Contains predicate on the "hostname" field.

func HostnameContainsFold

func HostnameContainsFold(v string) predicate.Server

HostnameContainsFold applies the ContainsFold predicate on the "hostname" field.

func HostnameEQ

func HostnameEQ(v string) predicate.Server

HostnameEQ applies the EQ predicate on the "hostname" field.

func HostnameEqualFold

func HostnameEqualFold(v string) predicate.Server

HostnameEqualFold applies the EqualFold predicate on the "hostname" field.

func HostnameGT

func HostnameGT(v string) predicate.Server

HostnameGT applies the GT predicate on the "hostname" field.

func HostnameGTE

func HostnameGTE(v string) predicate.Server

HostnameGTE applies the GTE predicate on the "hostname" field.

func HostnameHasPrefix

func HostnameHasPrefix(v string) predicate.Server

HostnameHasPrefix applies the HasPrefix predicate on the "hostname" field.

func HostnameHasSuffix

func HostnameHasSuffix(v string) predicate.Server

HostnameHasSuffix applies the HasSuffix predicate on the "hostname" field.

func HostnameIn

func HostnameIn(vs ...string) predicate.Server

HostnameIn applies the In predicate on the "hostname" field.

func HostnameLT

func HostnameLT(v string) predicate.Server

HostnameLT applies the LT predicate on the "hostname" field.

func HostnameLTE

func HostnameLTE(v string) predicate.Server

HostnameLTE applies the LTE predicate on the "hostname" field.

func HostnameNEQ

func HostnameNEQ(v string) predicate.Server

HostnameNEQ applies the NEQ predicate on the "hostname" field.

func HostnameNotIn

func HostnameNotIn(vs ...string) predicate.Server

HostnameNotIn applies the NotIn predicate on the "hostname" field.

func ID

func ID(id int) predicate.Server

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.Server

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.Server

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.Server

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.Server

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.Server

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.Server

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.Server

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.Server

IDNotIn applies the NotIn predicate on the ID field.

func NatsComponent

func NatsComponent(v bool) predicate.Server

NatsComponent applies equality check predicate on the "nats_component" field. It's identical to NatsComponentEQ.

func NatsComponentEQ

func NatsComponentEQ(v bool) predicate.Server

NatsComponentEQ applies the EQ predicate on the "nats_component" field.

func NatsComponentIsNil

func NatsComponentIsNil() predicate.Server

NatsComponentIsNil applies the IsNil predicate on the "nats_component" field.

func NatsComponentNEQ

func NatsComponentNEQ(v bool) predicate.Server

NatsComponentNEQ applies the NEQ predicate on the "nats_component" field.

func NatsComponentNotNil

func NatsComponentNotNil() predicate.Server

NatsComponentNotNil applies the NotNil predicate on the "nats_component" field.

func Not

Not applies the not operator on the given predicate.

func NotificationWorkerComponent

func NotificationWorkerComponent(v bool) predicate.Server

NotificationWorkerComponent applies equality check predicate on the "notification_worker_component" field. It's identical to NotificationWorkerComponentEQ.

func NotificationWorkerComponentEQ

func NotificationWorkerComponentEQ(v bool) predicate.Server

NotificationWorkerComponentEQ applies the EQ predicate on the "notification_worker_component" field.

func NotificationWorkerComponentIsNil

func NotificationWorkerComponentIsNil() predicate.Server

NotificationWorkerComponentIsNil applies the IsNil predicate on the "notification_worker_component" field.

func NotificationWorkerComponentNEQ

func NotificationWorkerComponentNEQ(v bool) predicate.Server

NotificationWorkerComponentNEQ applies the NEQ predicate on the "notification_worker_component" field.

func NotificationWorkerComponentNotNil

func NotificationWorkerComponentNotNil() predicate.Server

NotificationWorkerComponentNotNil applies the NotNil predicate on the "notification_worker_component" field.

func OcspComponent

func OcspComponent(v bool) predicate.Server

OcspComponent applies equality check predicate on the "ocsp_component" field. It's identical to OcspComponentEQ.

func OcspComponentEQ

func OcspComponentEQ(v bool) predicate.Server

OcspComponentEQ applies the EQ predicate on the "ocsp_component" field.

func OcspComponentIsNil

func OcspComponentIsNil() predicate.Server

OcspComponentIsNil applies the IsNil predicate on the "ocsp_component" field.

func OcspComponentNEQ

func OcspComponentNEQ(v bool) predicate.Server

OcspComponentNEQ applies the NEQ predicate on the "ocsp_component" field.

func OcspComponentNotNil

func OcspComponentNotNil() predicate.Server

OcspComponentNotNil applies the NotNil predicate on the "ocsp_component" field.

func Or

func Or(predicates ...predicate.Server) predicate.Server

Or groups predicates with the OR operator between them.

func Os

func Os(v string) predicate.Server

Os applies equality check predicate on the "os" field. It's identical to OsEQ.

func OsContains

func OsContains(v string) predicate.Server

OsContains applies the Contains predicate on the "os" field.

func OsContainsFold

func OsContainsFold(v string) predicate.Server

OsContainsFold applies the ContainsFold predicate on the "os" field.

func OsEQ

func OsEQ(v string) predicate.Server

OsEQ applies the EQ predicate on the "os" field.

func OsEqualFold

func OsEqualFold(v string) predicate.Server

OsEqualFold applies the EqualFold predicate on the "os" field.

func OsGT

func OsGT(v string) predicate.Server

OsGT applies the GT predicate on the "os" field.

func OsGTE

func OsGTE(v string) predicate.Server

OsGTE applies the GTE predicate on the "os" field.

func OsHasPrefix

func OsHasPrefix(v string) predicate.Server

OsHasPrefix applies the HasPrefix predicate on the "os" field.

func OsHasSuffix

func OsHasSuffix(v string) predicate.Server

OsHasSuffix applies the HasSuffix predicate on the "os" field.

func OsIn

func OsIn(vs ...string) predicate.Server

OsIn applies the In predicate on the "os" field.

func OsLT

func OsLT(v string) predicate.Server

OsLT applies the LT predicate on the "os" field.

func OsLTE

func OsLTE(v string) predicate.Server

OsLTE applies the LTE predicate on the "os" field.

func OsNEQ

func OsNEQ(v string) predicate.Server

OsNEQ applies the NEQ predicate on the "os" field.

func OsNotIn

func OsNotIn(vs ...string) predicate.Server

OsNotIn applies the NotIn predicate on the "os" field.

func UpdateMessage

func UpdateMessage(v string) predicate.Server

UpdateMessage applies equality check predicate on the "update_message" field. It's identical to UpdateMessageEQ.

func UpdateMessageContains

func UpdateMessageContains(v string) predicate.Server

UpdateMessageContains applies the Contains predicate on the "update_message" field.

func UpdateMessageContainsFold

func UpdateMessageContainsFold(v string) predicate.Server

UpdateMessageContainsFold applies the ContainsFold predicate on the "update_message" field.

func UpdateMessageEQ

func UpdateMessageEQ(v string) predicate.Server

UpdateMessageEQ applies the EQ predicate on the "update_message" field.

func UpdateMessageEqualFold

func UpdateMessageEqualFold(v string) predicate.Server

UpdateMessageEqualFold applies the EqualFold predicate on the "update_message" field.

func UpdateMessageGT

func UpdateMessageGT(v string) predicate.Server

UpdateMessageGT applies the GT predicate on the "update_message" field.

func UpdateMessageGTE

func UpdateMessageGTE(v string) predicate.Server

UpdateMessageGTE applies the GTE predicate on the "update_message" field.

func UpdateMessageHasPrefix

func UpdateMessageHasPrefix(v string) predicate.Server

UpdateMessageHasPrefix applies the HasPrefix predicate on the "update_message" field.

func UpdateMessageHasSuffix

func UpdateMessageHasSuffix(v string) predicate.Server

UpdateMessageHasSuffix applies the HasSuffix predicate on the "update_message" field.

func UpdateMessageIn

func UpdateMessageIn(vs ...string) predicate.Server

UpdateMessageIn applies the In predicate on the "update_message" field.

func UpdateMessageIsNil

func UpdateMessageIsNil() predicate.Server

UpdateMessageIsNil applies the IsNil predicate on the "update_message" field.

func UpdateMessageLT

func UpdateMessageLT(v string) predicate.Server

UpdateMessageLT applies the LT predicate on the "update_message" field.

func UpdateMessageLTE

func UpdateMessageLTE(v string) predicate.Server

UpdateMessageLTE applies the LTE predicate on the "update_message" field.

func UpdateMessageNEQ

func UpdateMessageNEQ(v string) predicate.Server

UpdateMessageNEQ applies the NEQ predicate on the "update_message" field.

func UpdateMessageNotIn

func UpdateMessageNotIn(vs ...string) predicate.Server

UpdateMessageNotIn applies the NotIn predicate on the "update_message" field.

func UpdateMessageNotNil

func UpdateMessageNotNil() predicate.Server

UpdateMessageNotNil applies the NotNil predicate on the "update_message" field.

func UpdateStatusEQ

func UpdateStatusEQ(v UpdateStatus) predicate.Server

UpdateStatusEQ applies the EQ predicate on the "update_status" field.

func UpdateStatusIn

func UpdateStatusIn(vs ...UpdateStatus) predicate.Server

UpdateStatusIn applies the In predicate on the "update_status" field.

func UpdateStatusIsNil

func UpdateStatusIsNil() predicate.Server

UpdateStatusIsNil applies the IsNil predicate on the "update_status" field.

func UpdateStatusNEQ

func UpdateStatusNEQ(v UpdateStatus) predicate.Server

UpdateStatusNEQ applies the NEQ predicate on the "update_status" field.

func UpdateStatusNotIn

func UpdateStatusNotIn(vs ...UpdateStatus) predicate.Server

UpdateStatusNotIn applies the NotIn predicate on the "update_status" field.

func UpdateStatusNotNil

func UpdateStatusNotNil() predicate.Server

UpdateStatusNotNil applies the NotNil predicate on the "update_status" field.

func UpdateStatusValidator

func UpdateStatusValidator(us UpdateStatus) error

UpdateStatusValidator is a validator for the "update_status" field enum values. It is called by the builders before save.

func UpdateWhen

func UpdateWhen(v time.Time) predicate.Server

UpdateWhen applies equality check predicate on the "update_when" field. It's identical to UpdateWhenEQ.

func UpdateWhenEQ

func UpdateWhenEQ(v time.Time) predicate.Server

UpdateWhenEQ applies the EQ predicate on the "update_when" field.

func UpdateWhenGT

func UpdateWhenGT(v time.Time) predicate.Server

UpdateWhenGT applies the GT predicate on the "update_when" field.

func UpdateWhenGTE

func UpdateWhenGTE(v time.Time) predicate.Server

UpdateWhenGTE applies the GTE predicate on the "update_when" field.

func UpdateWhenIn

func UpdateWhenIn(vs ...time.Time) predicate.Server

UpdateWhenIn applies the In predicate on the "update_when" field.

func UpdateWhenIsNil

func UpdateWhenIsNil() predicate.Server

UpdateWhenIsNil applies the IsNil predicate on the "update_when" field.

func UpdateWhenLT

func UpdateWhenLT(v time.Time) predicate.Server

UpdateWhenLT applies the LT predicate on the "update_when" field.

func UpdateWhenLTE

func UpdateWhenLTE(v time.Time) predicate.Server

UpdateWhenLTE applies the LTE predicate on the "update_when" field.

func UpdateWhenNEQ

func UpdateWhenNEQ(v time.Time) predicate.Server

UpdateWhenNEQ applies the NEQ predicate on the "update_when" field.

func UpdateWhenNotIn

func UpdateWhenNotIn(vs ...time.Time) predicate.Server

UpdateWhenNotIn applies the NotIn predicate on the "update_when" field.

func UpdateWhenNotNil

func UpdateWhenNotNil() predicate.Server

UpdateWhenNotNil applies the NotNil predicate on the "update_when" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

func Version

func Version(v string) predicate.Server

Version applies equality check predicate on the "version" field. It's identical to VersionEQ.

func VersionContains

func VersionContains(v string) predicate.Server

VersionContains applies the Contains predicate on the "version" field.

func VersionContainsFold

func VersionContainsFold(v string) predicate.Server

VersionContainsFold applies the ContainsFold predicate on the "version" field.

func VersionEQ

func VersionEQ(v string) predicate.Server

VersionEQ applies the EQ predicate on the "version" field.

func VersionEqualFold

func VersionEqualFold(v string) predicate.Server

VersionEqualFold applies the EqualFold predicate on the "version" field.

func VersionGT

func VersionGT(v string) predicate.Server

VersionGT applies the GT predicate on the "version" field.

func VersionGTE

func VersionGTE(v string) predicate.Server

VersionGTE applies the GTE predicate on the "version" field.

func VersionHasPrefix

func VersionHasPrefix(v string) predicate.Server

VersionHasPrefix applies the HasPrefix predicate on the "version" field.

func VersionHasSuffix

func VersionHasSuffix(v string) predicate.Server

VersionHasSuffix applies the HasSuffix predicate on the "version" field.

func VersionIn

func VersionIn(vs ...string) predicate.Server

VersionIn applies the In predicate on the "version" field.

func VersionLT

func VersionLT(v string) predicate.Server

VersionLT applies the LT predicate on the "version" field.

func VersionLTE

func VersionLTE(v string) predicate.Server

VersionLTE applies the LTE predicate on the "version" field.

func VersionNEQ

func VersionNEQ(v string) predicate.Server

VersionNEQ applies the NEQ predicate on the "version" field.

func VersionNotIn

func VersionNotIn(vs ...string) predicate.Server

VersionNotIn applies the NotIn predicate on the "version" field.

Types

type Channel

type Channel string

Channel defines the type for the "channel" enum field.

const (
	ChannelStable  Channel = "stable"
	ChannelTesting Channel = "testing"
	ChannelDevel   Channel = "devel"
)

Channel values.

func (Channel) String

func (c Channel) String() string

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Server queries.

func ByAgentWorkerComponent

func ByAgentWorkerComponent(opts ...sql.OrderTermOption) OrderOption

ByAgentWorkerComponent orders the results by the agent_worker_component field.

func ByArch

func ByArch(opts ...sql.OrderTermOption) OrderOption

ByArch orders the results by the arch field.

func ByCertManagerWorkerComponent

func ByCertManagerWorkerComponent(opts ...sql.OrderTermOption) OrderOption

ByCertManagerWorkerComponent orders the results by the cert_manager_worker_component field.

func ByChannel

func ByChannel(opts ...sql.OrderTermOption) OrderOption

ByChannel orders the results by the channel field.

func ByConsoleComponent

func ByConsoleComponent(opts ...sql.OrderTermOption) OrderOption

ByConsoleComponent orders the results by the console_component field.

func ByHostname

func ByHostname(opts ...sql.OrderTermOption) OrderOption

ByHostname orders the results by the hostname field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByNatsComponent

func ByNatsComponent(opts ...sql.OrderTermOption) OrderOption

ByNatsComponent orders the results by the nats_component field.

func ByNotificationWorkerComponent

func ByNotificationWorkerComponent(opts ...sql.OrderTermOption) OrderOption

ByNotificationWorkerComponent orders the results by the notification_worker_component field.

func ByOcspComponent

func ByOcspComponent(opts ...sql.OrderTermOption) OrderOption

ByOcspComponent orders the results by the ocsp_component field.

func ByOs

func ByOs(opts ...sql.OrderTermOption) OrderOption

ByOs orders the results by the os field.

func ByUpdateMessage

func ByUpdateMessage(opts ...sql.OrderTermOption) OrderOption

ByUpdateMessage orders the results by the update_message field.

func ByUpdateStatus

func ByUpdateStatus(opts ...sql.OrderTermOption) OrderOption

ByUpdateStatus orders the results by the update_status field.

func ByUpdateWhen

func ByUpdateWhen(opts ...sql.OrderTermOption) OrderOption

ByUpdateWhen orders the results by the update_when field.

func ByVersion

func ByVersion(opts ...sql.OrderTermOption) OrderOption

ByVersion orders the results by the version field.

type UpdateStatus

type UpdateStatus string

UpdateStatus defines the type for the "update_status" enum field.

const (
	UpdateStatusSuccess    UpdateStatus = "Success"
	UpdateStatusError      UpdateStatus = "Error"
	UpdateStatusPending    UpdateStatus = "Pending"
	UpdateStatusInProgress UpdateStatus = "In Progress"
)

UpdateStatus values.

func (UpdateStatus) String

func (us UpdateStatus) String() string

Jump to